hardshare
=========

Introduction
------------

**hardshare** is a system for sharing your robot hardware through the `rerobots
<https://rerobots.net/>`_ infrastructure.  It is in the early stages of
development. Until version 1.0.0, the protocol can change without warning.

This Python package provides the CLI and WebSocket-based daemon for the client
side. The official repository is at https://github.com/rerobots/hardshare
It is listed on PyPI at https://pypi.org/project/hardshare/

Recent releases of the full documentation are available at
https://hardshare.readthedocs.io/


License
-------

This is free software, released under the Apache License, Version 2.0.
You may obtain a copy of the License at

    https://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
